==> uclient-0.2.0.crate: uclient-0.2.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [0.2.0](https://github.com/fMeow/uclient/compare/v0.1.4...v0.2.0) (2021-05-28)


### Features

* multipart support, send read object ([323611e](https://github.com/fMeow/uclient/commit/323611eaab6277e2011b2ce1b04c8a2b7cbdd85d))


### Bug Fixes

* add uclient::Client ([7ec95ef](https://github.com/fMeow/uclient/commit/7ec95efefb51cc78589f2a22aed2857c75be0298))

### [0.1.4](https://github.com/fMeow/uclient/compare/v0.1.3...v0.1.4) (2021-05-27)


### Features

* request_bytes ([ff530e2](https://github.com/fMeow/uclient/commit/ff530e21849b598cf325a6e730e543da99cad057))

### [0.1.3](https://github.com/fMeow/uclient/compare/v0.1.2...v0.1.3) (2021-05-27)


### Bug Fixes

* async_surf_rustls ([b152f27](https://github.com/fMeow/uclient/commit/b152f27c7b97b951c4cefe04bcc7995224ef416f))

### [0.1.2](https://github.com/fMeow/uclient/compare/v0.1.1...v0.1.2) (2021-05-27)


### Features

* add async_surf_rustls ([2b5931c](https://github.com/fMeow/uclient/commit/2b5931cce41610deb9f54dd2fe476f025edc8457))

### [0.1.1](https://github.com/fMeow/uclient/compare/v0.1.0...v0.1.1) (2021-05-01)


### Bug Fixes

* surf client response header ([379c5a5](https://github.com/fMeow/uclient/commit/379c5a5f88cb7dfcda88ebd135511564a727b248))

## 0.1.0 (2021-03-28)


### Features

* universal interface ClientExt trait ([bc685c2](https://github.com/fMeow/uclient/commit/bc685c2a2fb5c6b62157b3bc614a779bf3a69702))

==> uclient-0.2.2.crate: uclient-0.2.2/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.2.2](https://github.com/fMeow/uclient/compare/v0.2.1...v0.2.2) (2021-05-29)


### Features

* add FormStream ([cc5135d](https://github.com/fMeow/uclient/commit/cc5135df77207034b212458d312c928599ee668c))
* use Form Stream ([78a2765](https://github.com/fMeow/uclient/commit/78a2765ec7ea5237bbafdce017ee4c7a51c8108d))

### [0.2.1](https://github.com/fMeow/uclient/compare/v0.2.0...v0.2.1) (2021-05-29)


### Features

* add method to turn into header ([04ba0bc](https://github.com/fMeow/uclient/commit/04ba0bca6201aac31a5abf2837144770b54ba1da))
* count bytes count of multipart `Read` object ([787a5f9](https://github.com/fMeow/uclient/commit/787a5f91b67039908bf06026a959e5a9c50c633d))
* guess mime for file ([1f4583e](https://github.com/fMeow/uclient/commit/1f4583e948511412afe11ba4e7759a722c909cd4))
* use crate::Error for `multipart_to_read()` ([e695847](https://github.com/fMeow/uclient/commit/e6958472c8a29ebbf05894888ecac6b61fd31433))


### Bug Fixes

* test ([5714e44](https://github.com/fMeow/uclient/commit/5714e4468e75a4f8176cc0289469225c072195eb))

## [0.2.0](https://github.com/fMeow/uclient/compare/v0.1.4...v0.2.0) (2021-05-28)


### Features

* multipart support, send read object ([323611e](https://github.com/fMeow/uclient/commit/323611eaab6277e2011b2ce1b04c8a2b7cbdd85d))


### Bug Fixes

* add uclient::Client ([7ec95ef](https://github.com/fMeow/uclient/commit/7ec95efefb51cc78589f2a22aed2857c75be0298))

### [0.1.4](https://github.com/fMeow/uclient/compare/v0.1.3...v0.1.4) (2021-05-27)


### Features

* request_bytes ([ff530e2](https://github.com/fMeow/uclient/commit/ff530e21849b598cf325a6e730e543da99cad057))

### [0.1.3](https://github.com/fMeow/uclient/compare/v0.1.2...v0.1.3) (2021-05-27)


### Bug Fixes

* async_surf_rustls ([b152f27](https://github.com/fMeow/uclient/commit/b152f27c7b97b951c4cefe04bcc7995224ef416f))

### [0.1.2](https://github.com/fMeow/uclient/compare/v0.1.1...v0.1.2) (2021-05-27)


### Features

* add async_surf_rustls ([2b5931c](https://github.com/fMeow/uclient/commit/2b5931cce41610deb9f54dd2fe476f025edc8457))

### [0.1.1](https://github.com/fMeow/uclient/compare/v0.1.0...v0.1.1) (2021-05-01)


### Bug Fixes

* surf client response header ([379c5a5](https://github.com/fMeow/uclient/commit/379c5a5f88cb7dfcda88ebd135511564a727b248))

## 0.1.0 (2021-03-28)


### Features

* universal interface ClientExt trait ([bc685c2](https://github.com/fMeow/uclient/commit/bc685c2a2fb5c6b62157b3bc614a779bf3a69702))
